Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(692)

Unified Diff: media/gpu/avda_codec_image.h

Issue 2461073002: Use MediaCodec.setOutputSurface() for fullscreen transitions on M. (Closed)
Patch Set: Address comments. Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/gpu/android_video_decode_accelerator.cc ('k') | media/gpu/avda_codec_image.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/gpu/avda_codec_image.h
diff --git a/media/gpu/avda_codec_image.h b/media/gpu/avda_codec_image.h
index 6d5e33d0ee5c669bb002f59d8537c34bdd3e4901..fcfcd43469ed4bcf19392edcb0e656ce81d19562 100644
--- a/media/gpu/avda_codec_image.h
+++ b/media/gpu/avda_codec_image.h
@@ -74,13 +74,14 @@ class AVDACodecImage : public gpu::gles2::GLStreamTextureImage {
void set_texture(gpu::gles2::Texture* texture) { texture_ = texture; }
- // Decoded buffer index that has the image for us to display.
- void set_media_codec_buffer_index(int buffer_index) {
- codec_buffer_index_ = buffer_index;
- }
+ // Sets up the properties necessary for the image to render. |buffer_index| is
+ // supplied to ReleaseOutputBuffer(), |has_surface_texture| controls which
+ // rendering path is used, and |size| is used by the compositor.
+ void SetBufferMetadata(int buffer_index,
+ bool has_surface_texture,
+ const gfx::Size& size);
- // Set the size of the current image.
- void set_size(const gfx::Size& size) { size_ = size; }
+ bool SetSharedState(scoped_refptr<AVDASharedState> shared_state);
// Indicates if the codec buffer has been released to the back buffer.
bool was_rendered_to_back_buffer() const {
@@ -92,6 +93,8 @@ class AVDACodecImage : public gpu::gles2::GLStreamTextureImage {
return codec_buffer_index_ == kRendered;
}
+ bool is_unrendered() const { return codec_buffer_index_ >= kUpdateOnly; }
+
protected:
~AVDACodecImage() override;
@@ -141,8 +144,9 @@ class AVDACodecImage : public gpu::gles2::GLStreamTextureImage {
const base::WeakPtr<gpu::gles2::GLES2Decoder> decoder_;
- // Indicates if we're rendering to a SurfaceTexture or not.
- const bool has_surface_texture_;
+ // Indicates if we're rendering to a SurfaceTexture or not. Set during the
+ // call to SetBufferMetadata().
+ bool has_surface_texture_;
// The texture that we're attached to.
gpu::gles2::Texture* texture_;
« no previous file with comments | « media/gpu/android_video_decode_accelerator.cc ('k') | media/gpu/avda_codec_image.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698